1.14.2 — Rucio 1.2 documentation

# 1.14.2

## General

### Enhancements

- Core & Internals: db: fix sqlalchemy text conversion #288
- Documentation: Adapt setup.py for buildthedocs #285
- Infrastructure: Include postgres client into the CC7 docker image #282
- Probes & Alarms: Upload/download probe for rucio-clients #272
- Release management: Add Extras dependency on the possible rucio backend (oracle, mysql, postgresql) #281
- Testing: Enable travis postgresql tests #280

### Bugs

- Core & Internals: Make all queries fully postgresql compatible #265
- Documentation: Fixed badly merged conf.py file #307

## WebUI

### Enhancements

- WebUI: Policy-based generation of RucioUI pages #245